@@ -105,7 +105,6 @@ INSERT INTO global_suppressions VALUES
  */
 
  ("Got error [0-9]* when reading table"),
- ("Incorrect definition of table"),
  ("Incorrect information in file"),
  ("InnoDB: Warning: we did not need to do crash recovery"),
  /*("Invalid \\(old\\?\\) table or database name"),*/
@@ -141,7 +140,7 @@ INSERT INTO global_suppressions VALUES
  ("You have an error in your SQL syntax"),
  ("deprecated"),
  ("description of time zone"),
- ("equal MySQL server ids"),
+ ("equal MariaDB server ids"),
  ("error .*connecting to master"),
  ("error reading log entry"),
  ("lower_case_table_names is set"),
@@ -157,6 +156,10 @@ INSERT INTO global_suppressions VALUES
  ("InnoDB: Error: table `test`.`t[123]` .*does not exist in the InnoDB internal"),
  ("InnoDB: Warning: semaphore wait:"),
 
+ /* MDEV-28976: Tests that kill the server do not ensure that the
+ old process has terminated before starting a new one */
+ ("InnoDB: Unable to lock"),
+
  /*
    BUG#32080 - Excessive warnings on Solaris: setrlimit could not
    change the size of core files
@@ -170,13 +173,13 @@ INSERT INTO global_suppressions VALUES
 
  /* Added 2009-08-XX after fixing Bug #42408 */
 
- ("Although a path was specified for the .* option, log tables are used"),
+ ("Although a .* file was specified, log tables are used. To enable logging to files "),
  ("Backup: Operation aborted"),
  ("Restore: Operation aborted"),
  ("Restore: The grant .* was skipped because the user does not exist"),
  ("The path specified for the variable .* is not a directory or cannot be written:"),
  ("Master server does not support or not configured semi-sync replication, fallback to asynchronous"),
- (": The MySQL server is running with the --secure-backup-file-priv option so it cannot execute this statement"),
+ (": The MariaDB server is running with the --secure-backup-file-priv option so it cannot execute this statement"),
  ("Slave: Unknown table 't1' error.* 1051"),
 
  /* Maria storage engine dependent tests */
